ShotRecord
ShotRecord(
path,
coordinates,
fileheader,
rec_depth_key='RecGroupElevation',
depth_key='SourceDepth',
by_receiver=False,
segments=list(),
summary=dict(),
ns=0,
dt=0,
fs=None,
)Information about a single shot or receiver gather within a SEGY file.
Attributes
| Name | Description |
|---|---|
| by_receiver | bool(x) -> bool |
| data | The traces of this record, read when they are indexed. |
| depth_key | str(object=’’) -> str |
| dt | int([x]) -> integer |
| ns | int([x]) -> integer |
| ntraces | Number of traces in this record. |
| rec_coordinates | Array of receiver coordinates for this gather. |
| rec_depth_key | str(object=’’) -> str |
| traceheaders | Load trace headers for all shots on first access. |
Methods
| Name | Description |
|---|---|
| read_data | Load the traces of this shot. |
| read_headers | Read only the headers for this shot. |
read_data
read_data(keys=None, traces=None)Load the traces of this shot.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| keys | Iterable[str] | Header fields to load with each trace. | None |
| traces | slice | Range of this record’s traces to load. Only the corresponding part of the file is read; by default all traces are. | None |
Returns
| Name | Type | Description |
|---|---|---|
| ndarray | ns x number of traces read. |
read_headers
read_headers(keys=None)Read only the headers for this shot.